Crate metaculustetra

Crate metaculustetra 

A library for interacting with Metaculus.

Repository

Modules

index
A module for creating indices. Indices are the weighted sums of multiple questions that relate to a single topic, intended to give an overall view of how the topic is doing, as described here.

Structs

Metaculus
An API client for retrieving Metaculus question data. Contains the domain (e.g. www, pandemic, ai) of the Metaculus instance and the blocking reqwest client.
Question
Data on a single Metaculus question.

Enums

Prediction
An aggregated overall prediction on a Metaculus question.